/****************************************************************************************

	Space Invaders Multigame

*******************************************************************************************/

#include "driver.h"
#include "invaders.h"
#include "sound/samples.h"
#include "sound/sn76477.h"
#include "machine/mb14241.h"



/*************************************
 *
 *  Sound
 *
 *************************************/


static WRITE8_HANDLER( invaders_03_w )
{
	UINT8 rising_bits = data & ~port_1_last;

	sn76477_enable_w(0, !(data & 0x01));			/* SAUCER SOUND */

	if (rising_bits & 0x02) sample_start_n(0, 0, 0, 0);	/* MISSILE SOUND */
	if (rising_bits & 0x04) sample_start_n(0, 1, 1, 0);	/* EXPLOSION */
	if (rising_bits & 0x08) sample_start_n(0, 2, 2, 0);	/* INVADER HIT */
	if (rising_bits & 0x10) sample_start_n(0, 5, 8, 0);	/* BONUS MISSILE BASE */

	screen_red = data & 0x04;

	sound_global_enable(data & 0x20);

	if (data & 0xc0) printf("3=%X ",data);

	port_1_last = data;
}

static WRITE8_HANDLER( invaders_05_w )
{
	/* FLEET (movement)

       DO = 20K + 20K
       D1 = 68K
       D2 = 82K
       D3 = 100K */

	UINT8 rising_bits = data & ~port_2_last;

	if (rising_bits & 0x01) sample_start_n(0, 4, 3, 0);	/* FLEET */
	if (rising_bits & 0x02) sample_start_n(0, 4, 4, 0);	/* FLEET */
	if (rising_bits & 0x04) sample_start_n(0, 4, 5, 0);	/* FLEET */
	if (rising_bits & 0x08) sample_start_n(0, 4, 6, 0);	/* FLEET */
	if (rising_bits & 0x10) sample_start_n(0, 3, 7, 0);	/* SAUCER HIT */

	player = data & 0x20;
	flipscreen = player & input_port_read(machine, "CAB");

	if (data & 0xc0) printf("5=%X ",data);

	port_2_last = data;
}




/*************************************
 *
 *  Address Maps
 *
 *************************************/

static ADDRESS_MAP_START( simg_map, ADDRESS_SPACE_PROGRAM, 8 )
	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
	AM_RANGE(0x0000, 0x1fff) AM_ROM AM_WRITENOP
	AM_RANGE(0x2000, 0x3fff) AM_RAM AM_BASE(&invaders_ram) AM_SIZE(&invaders_ram_size)
	AM_RANGE(0x4000, 0x5fff) AM_ROM AM_WRITENOP
	AM_RANGE(0x6000, 0x63ff) AM_RAM
ADDRESS_MAP_END

static ADDRESS_MAP_START( simg_io_map, ADDRESS_SPACE_IO, 8 )
	//ADDRESS_MAP_GLOBAL_MASK(0x7)
	AM_RANGE(0x00, 0x00) AM_MIRROR(0x04) AM_READ_PORT("IN0")
	AM_RANGE(0x01, 0x01) AM_MIRROR(0x04) AM_READ_PORT("IN1")
	AM_RANGE(0x02, 0x02) AM_MIRROR(0x04) AM_READ(invaders_02_r)
	AM_RANGE(0x03, 0x03) AM_MIRROR(0x04) AM_READ(mb14241_0_shift_result_r)

	AM_RANGE(0x02, 0x02) AM_WRITE(mb14241_0_shift_count_w)
	AM_RANGE(0x03, 0x03) AM_WRITE(invaders_03_w)
	AM_RANGE(0x04, 0x04) AM_WRITE(mb14241_0_shift_data_w)
	AM_RANGE(0x05, 0x05) AM_WRITE(invaders_05_w)
	AM_RANGE(0x06, 0x06) AM_WRITE(watchdog_reset_w)
ADDRESS_MAP_END



/*************************************
 *
 *  Inputs
 *
 *************************************/

static INPUT_PORTS_START( simg )
	PORT_START("IN0")
	PORT_BIT( 0x40, IP_ACTIVE_LOW,  IPT_UNUSED )
	PORT_BIT( 0xbf, IP_ACTIVE_HIGH, IPT_UNUSED )

	PORT_START("IN1")
	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_COIN1 )
	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_START2 )
	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START1 )
	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNKNOWN )
	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 )
	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY
	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY
	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_UNKNOWN )

	PORT_START("IN2")
	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ) )		PORT_DIPLOCATION("SW1:1,2")
	PORT_DIPSETTING(    0x00, "2" )
	PORT_DIPSETTING(    0x01, "3" )
	PORT_DIPSETTING(    0x02, "4" )
	PORT_DIPSETTING(    0x03, "5" )
	PORT_DIPUNKNOWN_DIPLOC( 0x04, 0x00, "SW1:3" )
	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Bonus_Life ) )	PORT_DIPLOCATION("SW1:4")
	PORT_DIPSETTING(    0x00, "3000" )
	PORT_DIPSETTING(    0x08, "5000" )
	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)			PORT_DIPLOCATION("SW1:5")
	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(2)	PORT_DIPLOCATION("SW1:6")
	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(2)	PORT_DIPLOCATION("SW1:7")
	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Coinage ) )					PORT_DIPLOCATION("SW1:8")
	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )

	INVADERS_CAB(0x20)
INPUT_PORTS_END


/*************************************
 *
 *  Machine Drivers
 *
 *************************************/

static MACHINE_DRIVER_START( simg )

	/* basic machine hardware */
	MDRV_CPU_ADD("main",8080,INVADERS_CPU_CLOCK)
	MDRV_CPU_PROGRAM_MAP(simg_map,0)
	MDRV_CPU_IO_MAP(simg_io_map,0)
	MDRV_WATCHDOG_VBLANK_INIT(255)
	MDRV_MACHINE_START(invaders_common)
	MDRV_MACHINE_RESET(invaders_common)

	/* video hardware */
	MDRV_VIDEO_UPDATE(invaders) //(invadpt2)

	MDRV_SCREEN_ADD("main", RASTER)
	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
	MDRV_SCREEN_RAW_PARAMS(INVADERS_PIXEL_CLOCK, INVADERS_HTOTAL, INVADERS_HBEND, INVADERS_HPIXCOUNT, INVADERS_VTOTAL, INVADERS_VBEND, INVADERS_VBSTART)

	/* sound hardware */
	MDRV_IMPORT_FROM(invaders_samples_audio)
MACHINE_DRIVER_END

DRIVER_INIT( simg )
{
	int i,j;
	UINT32 block1[]={ 0, 0x800, 0x200, 0xa00, 0x100, 0x900, 0x300, 0xb00 };
	UINT32 block2[]={ 0, 0x4000, 0x2000, 0x6000, 0x1000, 0x5000, 0x3000, 0x7000 };

	/* Data lines swapped */
	UINT8 *RAM = memory_region(machine, "main");
	for (i = 0x40000; i < memory_region_length(machine, "main"); i++)
		RAM[i] = BITSWAP8(RAM[i],0,6,5,7,4,3,1,2);

	/* Address lines pass through an undumped unnamed 24-pin prom - so we have to guess */
	/* to, from, size */
	for (i = 0; i < 8; i++)
		for (j = 0; j < 8; j++)
			memcpy(&RAM[0x20000 | i<<11 | j<<8], &RAM[0x140000 | block2[i] | block1[j]], 0x100);

	memcpy(&RAM[0x0000], &RAM[0x20000], 0x2000);
	memcpy(&RAM[0x4000], &RAM[0x22000], 0x2000);

	for (i = 0; i < 8; i++)
		for (j = 0; j < 8; j++)
			memcpy(&RAM[0x24000 | i<<11 | j<<8], &RAM[0x140400 | block2[i] | block1[j]], 0x100);

	for (i = 0; i < 8; i++)
		for (j = 0; j < 8; j++)
			memcpy(&RAM[0x28000 | i<<11 | j<<8], &RAM[0x148000 | block2[i] | block1[j]], 0x100);

	for (i = 0; i < 8; i++)
		for (j = 0; j < 8; j++)
			memcpy(&RAM[0x2c000 | i<<11 | j<<8], &RAM[0x148400 | block2[i] | block1[j]], 0x100);

	for (i = 0; i < 8; i++)
		for (j = 0; j < 8; j++)
			memcpy(&RAM[0x30000 | i<<11 | j<<8], &RAM[0x150000 | block2[i] | block1[j]], 0x100);

	for (i = 0; i < 8; i++)
		for (j = 0; j < 8; j++)
			memcpy(&RAM[0x34000 | i<<11 | j<<8], &RAM[0x150400 | block2[i] | block1[j]], 0x100);

	for (i = 0; i < 8; i++)
		for (j = 0; j < 8; j++)
			memcpy(&RAM[0x38000 | i<<11 | j<<8], &RAM[0x158000 | block2[i] | block1[j]], 0x100);

	for (i = 0; i < 8; i++)
		for (j = 0; j < 8; j++)
			memcpy(&RAM[0x3c000 | i<<11 | j<<8], &RAM[0x158400 | block2[i] | block1[j]], 0x100);
}

/*************************************
 *
 *  Roms
 *
 *************************************/

ROM_START( simg )
	ROM_REGION( 0x160000, "main", 0 )
	ROM_LOAD( "s10.bin",      0x040000, 0x20000, CRC(1b43e4d3) SHA1(c50decd9caaec7f2d8b3ba74f718372d31bc1c3b) )
	ROM_LOAD( "s081a.bin",    0x060000, 0x20000, CRC(daa77345) SHA1(0fdc9c2a6d9c0aa3233c5d31433adb1ea4e5b250) )
	ROM_LOAD( "s082a.bin",    0x080000, 0x20000, CRC(25f0f17e) SHA1(a3ccf823399e23dd9fdb38fd58c0acfe80b57fe3) )
	ROM_LOAD( "s083a.bin",    0x0a0000, 0x20000, CRC(f426d43b) SHA1(a299472f1d65f356ec01ca7cc8d3039abac20019) )
	ROM_LOAD( "m801a.bin",    0x0c0000, 0x20000, CRC(f28536d2) SHA1(08ef3ea3fac38c7a478f094bfa7c369ac39515c4) )
	ROM_LOAD( "m802a.bin",    0x0e0000, 0x20000, CRC(8079b1d0) SHA1(b13d910f314550eef468ee819b92788d2a002d82) )
	ROM_LOAD( "m802c.bin",    0x100000, 0x20000, CRC(5b537de5) SHA1(4d8a6b622b818e88383d011c25f8f34b7372db6d) )
	ROM_LOAD( "m803a.bin",    0x120000, 0x20000, CRC(6d538828) SHA1(9a80c67abd32c4c8cd04320501a2aa4e2a308fc9) )
	ROM_LOAD( "m803d.bin",    0x140000, 0x20000, CRC(6a62cb3c) SHA1(eb7b567098ad596859f417dd5c59c2cf1ebf1154) )

//	ROM_REGION( 0x0800, "proms", 0 )
//	ROM_LOAD( "cv01-7643.2c", 0x0000, 0x0400, CRC(aac24f34) SHA1(ad110e776547fb48baac568bb50d61854537ca34) )
//	ROM_LOAD( "cv02-7643.1c", 0x0400, 0x0400, CRC(2bdf83a0) SHA1(01ffbd43964c41987e7d44816271308f9a70802b) )
ROM_END

/*************************************
 *
 *  Game Drivers
 *
 *************************************/

/*   year  game  parent machine input init orientation */

GAME(2002, simg, 0,     simg,   simg, simg,   ROT270,    "Scott Brasington", "Space Invaders Multigame", GAME_SUPPORTS_SAVE | GAME_NOT_WORKING )
