/******************************************************************************

    driver.c

    Copyright (c) 1996-2007, Nicola Salmoria and the MAME Team.
    Visit http://mamedev.org for licensing and usage restrictions.

    The list of all available drivers. Drivers have to be included here to be
    recognized by the executable.

    To save some typing, we use a hack here. This file is recursively #included
    twice, with different definitions of the DRIVER() macro. The first one
    declares external references to the drivers; the second one builds an array
    storing all the drivers.

******************************************************************************/

#include "driver.h"


#ifndef DRIVER_RECURSIVE

#define DRIVER_RECURSIVE

/* step 1: declare all external references */
#define DRIVER(NAME) extern game_driver driver_##NAME;
#include "mis_driv.c"

/* step 2: define the drivers[] array */
#undef DRIVER
#define DRIVER(NAME) &driver_##NAME,
const game_driver * const drivers[] =
{
#include "mis_driv.c"
	0	/* end of array */
};

#else	/* DRIVER_RECURSIVE */


	DRIVER( eyes )		/* (c) 1982 Digitrex Techstar + "Rockola presents" */
	DRIVER( mspacman )	/* (c) 1981 Midway */ /* made by Gencomp */

	DRIVER( pengo )		/* 834-0386 (c) 1982 Sega */

	DRIVER( jrpacman )	/* (c) 1983 Midway */

	DRIVER( pisces )	/* Subelectro */
	DRIVER( mooncrst )	/* (c) 1980 Nichibutsu */
	/* "Scramble hardware" (and variations) games */
	DRIVER( scramble )	/* GX387 (c) 1981 Konami */
	DRIVER( frogger )	/* GX392 (c) 1981 Konami */
	DRIVER( amidar )	/* GX337 (c) 1981 Konami */

	/* "Crazy Climber hardware" games */
	DRIVER( ckong )		/* (c) 1981 Falcon */
	DRIVER( terracre )	/* (c) 1985 */

	/* Nichibutsu Mahjong games */

	DRIVER( phoenix )	/* (c) 1980 Amstar */
	DRIVER( galaga )	/* (c) 1981 */
	DRIVER( xevious )	/* (c) 1982 */
	DRIVER( superpac )	/* (c) 1982 */
	DRIVER( mappy )		/* (c) 1983 */
	/* no custom I/O in the following, HD63701 (or compatible) microcontroller instead */
	DRIVER( pacland )	/* (c) 1984 */

	/* Namco System 86 games */
	DRIVER( mrdo )		/* (c) 1982 */
	DRIVER( docastle )	/* (c) 1983 */
	DRIVER( dorunrun )	/* (c) 1984 */
	DRIVER( dkong )		/* (c) 1981 Nintendo of America */

	/* Nintendo Playchoice 10 games */
	DRIVER( playch10 )
	DRIVER( suprmrio )	/* (c) 1986 Nintendo */
	DRIVER( invaders )	/* 739 [1979] */
	DRIVER( sstrangr )
	DRIVER( sstrngr2 )
	DRIVER( galxwars )
	DRIVER( rollingc )	/* Nichibutsu */
	DRIVER( ozmawars )	/* Shin Nihon Kikaku (SNK) */
	DRIVER( schaser )	/* RT  Taito */
	DRIVER( schasrcv )	/* RT  Taito */
	DRIVER( lupin3 )	/* LP  (c) 1980 Taito */
	DRIVER( lupin3a )	/* LP  (c) 1980 Taito */
	DRIVER( darthvdr )
	DRIVER( ballbomb )
	DRIVER( sarge )		/* (c) 1985 */
	DRIVER( mpatrol )	/* M52 (c) 1982 */
	DRIVER( qbert )		/* GV-103 (c) 1982 Gottlieb */

	DRIVER( bublbobl )	/* A78 (c) 1986 Taito Corporation */
	DRIVER( rastan )	/* B04 (c) 1987 Taito Corporation Japan (World) */
	DRIVER( arkanoid )	/* A75 (c) 1986 Taito Corporation Japan (World) */
	DRIVER( dariusg )	/* D87 (c) 1994 Taito Corporation Japan (World) */
	DRIVER( twincobr )	/* TP-011 (c) 1987 Taito Corporation (World) */
	DRIVER( commando )	/*  5/1985 (c) 1985 (World) */
	DRIVER( ghouls )	/* 12/1988 (c) 1988 (World) */
	DRIVER( cawing )	/* 12/10/1990 (c) 1990 (World) */
	DRIVER( kod )		/* 11/07/1991 (c) 1991 (World) */
	DRIVER( captcomm )	/* 14/10/1991 (c) 1991 (World) */
	DRIVER( knights )	/* 27/11/1991 (c) 1991 (World) */
	DRIVER( sf2ce )		/* 13/03/1992 (c) 1992 (World) */
	DRIVER( sf2m1 )		/* hack */
	DRIVER( sf2m3 )		/* hack */
	DRIVER( wof )		/* 02/10/1992 (c) 1992 (World) (CPS1 + QSound) */
	DRIVER( dino )		/* 01/02/1993 (c) 1993 (World) (CPS1 + QSound) */
	DRIVER( punisher )	/* 22/04/1993 (c) 1993 (World) (CPS1 + QSound) */
	DRIVER( armwar )	/* 24/10/1994 (c) 1994 (Euro) */
	DRIVER( wbml )		/* bootleg (S2) */
	DRIVER( btime )		/* (c) 1982 */
	DRIVER( pcktgal )	/* (c) 1987 Data East Corporation (Japan) */
	DRIVER( bombjack )	/* (c) 1984 Tehkan */
	DRIVER( tehkanwc )	/* (c) 1985 Tehkan */
	DRIVER( yiear )		/* GX407 (c) 1985 */
	DRIVER( tempest )	/* 136002           (c) 1980 */
	DRIVER( centiped )	/* 136001           (c) 1980 */
	DRIVER( milliped )	/* 136013           (c) 1982 */
	/* Gauntlet 2 */
	DRIVER( gaunt2 )	/* 136043           (c) 1986 */
	/* Gauntlet 2 - 2 Player */

	/* Neo Geo games */
	/* the four digits number is the game ID stored at address 0x0108 of the program ROM */
	/* info on prototypes taken from http://www.members.tripod.com/fresa/proto/puzzle.htm */
	DRIVER( neogeo )
	DRIVER( nam1975 )	/* 0001 (c) 1990 SNK */
	DRIVER( samsho )	/* 0045 (c) 1993 SNK */
				/* 0054 Crossed Swords 2  (CD only? not confirmed, MVS might exist) */
	DRIVER( kof94 )		/* 0055 (c) 1994 SNK */
	DRIVER( aof2 )		/* 0056 (c) 1994 SNK */
	DRIVER( samsho2 )	/* 0063 (c) 1994 SNK */
	DRIVER( fatfury3 )	/* 0069 (c) 1995 SNK */
	DRIVER( zupapa )	/* 0070 Zupapa - released in 2001, 1994 prototype probably exists */
				/* 0071 Bang Bang Busters (prototype) 1994 Visco */
				/* 0072 Last Odyssey Pinball Fantasia (prototype) 1995 Monolith */
	DRIVER( doubledr )	/* 0082 (c) 1995 Technos */
	DRIVER( pbobblen )	/* 0083 (c) 1994 Taito */
	DRIVER( kof95 )		/* 0084 (c) 1995 SNK */
	DRIVER( samsho3 )	/* 0087 (c) 1995 SNK */
	DRIVER( whp )		/* 0090 (c) 1995 ADK / SNK */
				/* 0091 */
	DRIVER( kabukikl )	/* 0092 (c) 1995 Hudson */
	DRIVER( kof96 )		/* 0214 (c) 1996 SNK */
	DRIVER( ninjamas )	/* 0217 (c) 1996 ADK / SNK */
				/* 0220 Choutetsu Brikin'ger - iron clad (MVS existance seems to have been confirmed) */
	DRIVER( samsho4 )	/* 0222 (c) 1996 SNK */
	DRIVER( rbffspec )	/* 0223 (c) 1996 SNK */
	DRIVER( kof97 )		/* 0232 (c) 1997 SNK */
	DRIVER( lastblad )	/* 0234 (c) 1997 SNK */
	DRIVER( rbff2 )		/* 0240 (c) 1998 SNK */
	DRIVER( mslug2 )	/* 0241 (c) 1998 SNK */
	DRIVER( kof98 )		/* 0242 (c) 1998 SNK */
	DRIVER( lastbld2 )	/* 0243 (c) 1998 SNK */
	DRIVER( mslugx )	/* 0250 (c) 1999 SNK */
	DRIVER( kof99 )		/* 0251 (c) 1999 SNK */
	DRIVER( ganryu )	/* 0252 (c) 1999 Visco */
	DRIVER( s1945p )	/* 0254 (c) 1999 Psikyo */
	DRIVER( preisle2 )	/* 0255 (c) 1999 Yumekobo */
	DRIVER( mslug3 )	/* 0256 (c) 2000 SNK */
	DRIVER( kof2000 )	/* 0257 (c) 2000 SNK */
				/* 0258 SNK vs. Capcom? */
	DRIVER( nitd )		/* 0260 (c) 2000 Eleven / Gavaking */
	DRIVER( sengoku3 )	/* 0261 (c) 2001 SNK */
	DRIVER( kof2001 )	/* 0262 (c) 2001 Eolith / SNK */
	DRIVER( mslug4 )	/* 0263 (c) 2002 Mega Enterprise */
	DRIVER( rotd )		/* 0264 (c) 2002 Evoga */
	DRIVER( kof2002 )	/* 0265 (c) 2002 Eolith / Playmore */
	DRIVER( matrim )	/* 0266 (c) 2002 Atlus */
	DRIVER( mslug5 )	/* 0268 (c) 2003 Playmore */
	DRIVER( svc )		/* 0269 (c) 2003 Playmore / Capcom */
	DRIVER( samsho5 )	/* 0270 (c) 2003 Playmore */
	DRIVER( samsh5sp )	/* 0272 (c) 2003 Playmore */
	DRIVER( mk )		/* (c) 1992 Midway */
	DRIVER( mk3 )		/* (c) 1994 Midway */

	/* IGS PGM System Games */
	DRIVER( pgm )	/* (c) 1997 */

	/* -- Misfitmame -- */

	/* 1942.c */
	DRIVER( galagax ) 	/* Jerky - Chris Moore hack of 1942 */

	/* arkanoid.c */
	DRIVER( akblc2dx ) 	/* hack */
	DRIVER( akgcdx ) 	/* hack */
	DRIVER( aktaytdx ) 	/* hack */
	DRIVER( arkll32 ) 	/* LLMAME 32 */

	/* asteroid.c */
	DRIVER( asteroi6 )	/* Clay Cowgill Bullet Hack */
	DRIVER( astdelu4 )

	/* astinvad.c */
	DRIVER( spacein2 )	/* [1980] Shoei */

	/* astrocde.c */
	DRIVER( tst_gorf )	/* Gorf test rom */
	DRIVER( tst_gor1 )	/* Gorf test rom */
	DRIVER( tst_wow2 )	/* Wow test rom */
	DRIVER( tst_wow3 )	/* Wow test rom */

	/* astrof.c */
	DRIVER( astrf_bl )	/* Black Background */

	/* bagman.c */
	DRIVER( bagturbo )
	DRIVER( pickinpi )	/* Color Hack by Pi */

	/* blktiger.c */
	DRIVER( blkdrgnk )	/* Korean Translation */

	/* bombjack.c */
	DRIVER( bmbjckgr )	/* Vag @ GreekRoms */
	DRIVER( bmbjckhs )	/* JROK */
	DRIVER( bombjckb )	/* bootleg */
	DRIVER( bombjred )	/* hack by unknown French person */

	/* btime.c */
	DRIVER( bnjr )		/* Bump N Jump Reverse Mod */
	DRIVER( btimehs )	/* (c) 1982 */
	DRIVER( btimemhs )	/* (c) 1982 + Midway */
	DRIVER( pnc )		/* Pac N Chase */
	DRIVER( stictime )	/* Marks Hack of btime */
	DRIVER( vecbtime )	/* T-Bone hack of Burgertime */

	/* bublbobl.c */
	DRIVER( bb2bmh )	/* Overclocked Bubblebobble Memories Hack */
	DRIVER( bbhackv1 ) 	/* OVerclocked Level Hack */ 
	DRIVER( bublbobf ) 	/* Arkatrad */ 

	/* bwidow.c */
//	DRIVER( spacwarp )	/* Hendrix - Proto on Space Duel HW - removed - not working */
	DRIVER( bwidowa )	/* This is the real release - the one in mame is a prototype */

	/* cclimber.c */
	DRIVER( tongypac )
	DRIVER( ckonghs )	/* High score save */
	DRIVER( ckongfix )	/* Graphics Fix */
	DRIVER( ckonga2 )
	DRIVER( ckonga3 )
	DRIVER( cclimbrm )	/* Tim Arcadecollecting Modded Version */

	/* centiped.c */
	DRIVER( astroped )	/* Twisty Hack of Centipede */
	DRIVER( astropd2 )	/* Twisty Hack of Centipede */
	DRIVER( cemescry )	/* NoSync hack of Centipede */
	DRIVER( killiped )	/* The Dog hack of Centipede */
	DRIVER( pacipede )	/* Jeff Coleburn hack of Centiped */
	DRIVER( silliped )	/* Andy hack of Millipede */
	DRIVER( vectiped )	/* The Dog hack of Centipede */
	DRIVER( vectrped )	/* T-Bone hack of Centipede */
	DRIVER( centipb )	/* bootleg of centipdb */
	DRIVER( magworm2 )	/* bootleg of magworm */

	/* cinemat.c */
	DRIVER( bbugtest )	/* Test Rom */

	/* commando.c */
	DRIVER( comdelux )	/* Twisty Hack */
	DRIVER( comdlux1 )	/* Twisty Hack */

	/* cps1mis.c */
	DRIVER( captcomh )	/* Found in neht build */
	DRIVER( cawingb )	/* bootleg */
//	DRIVER( daimakb )	/* Found in Mame Plus - taken out - doesn't boot */
	DRIVER( dinob )		/* 1993 Cadillacs and Dinosaurs (bootleg) */
	DRIVER( dinoeh )
	DRIVER( dinoh )		/* 1993 Cadillacs and Dinosaurs (Hack) */
	DRIVER( dinoha )	/* 1993 Cadillacs and Dinosaurs (Hack) */
	DRIVER( dinohb )	/* 1993 Cadillacs and Dinosaurs (Hack) */
///	DRIVER( dinohc )	/* Found in Mame Plus - need roms */
//	DRIVER( dynwarjh )	/* Found in neht build - taken out - not working */
//	DRIVER( dynwarj2 )	/* Found in neht build - taken out - not working */
	DRIVER( knightsb )
	DRIVER( knightsc )	/* real bootleg - not working */
	DRIVER( knightsh )	/* 1991 Knights of the Round (Hack) */
	DRIVER( knigtsha )	/* 1991 Knights of the Round (Hack) */
	DRIVER( kodh )
	DRIVER( pnicku )	/* 06/08/1994 (c) 1994 + Compile license (Japan) not listed on Capcom's site */
	DRIVER( punishjh )	/* Found in neht build */
	DRIVER( punishrb )	/* Found in neht build */
//	DRIVER( punishrh )	/* Found in Mame Plus - taken out - roms not available */
//	DRIVER( sf2b )		/* Found in Mame Plus - not working - suspected bad dumps */
	DRIVER( sf2ceh )	/* hack, Hispanic 990804 */
	DRIVER( sf2cebr )	/* hack, Brasil   920313 */
	DRIVER( sf2m8 )		/* hack */
	DRIVER( sf2m9 )		/* Found in Mame Plus */
	DRIVER( sf2m10 )	/* Found in Mame Plus */
	DRIVER( sf2m11 )	/* Found in Mame Plus */
	DRIVER( sf2m12 )	/* Found in Mame Plus */
	DRIVER( sf2m12a )	/* hack */
	DRIVER( sf2m13 )	/* hack */
	DRIVER( sf2mdt1 )	/* European bootleg */
//	DRIVER( sf2th )		/* Found in Mame Plus - not working - bad dump */
	DRIVER( sf2tlona )	/* hack, Tu Long set 1 */
	DRIVER( sf2tlonb )	/* hack, Tu Long set 2 */
	DRIVER( sf2turyu )	/* hack, Tu Long prototype */
	DRIVER( wofah )		/* 1992 Sangokushi II (Hack) */
	DRIVER( wofb )
	DRIVER( woffr )		/* Neo-Arc French Trans */
	DRIVER( wofjh )
//	DRIVER( wofjha )	/* taken out - it never worked */
	DRIVER( wof3js )	/* 1997  Three Sword Masters / San Jian Sheng */
	DRIVER( wofsjb )	/* 1995  Holy Sword Three Kingdoms / Sheng Jian San Guo */
	DRIVER( sfach )		/* 1995 Street Fighter Alpha (Publicity CPS Changer) */
	DRIVER( sfzch )		/* 1995 Street Fighter Zero (CPS Changer) */
	DRIVER( sfzbch )	/* 1995 Street Fighter Alpha (Brazil Hack CPS Changer) */
	DRIVER( wofch )		/* 1992 Tenchi Wo Kurau 2 (CPS Changer) */

	/* cps1hack.c */
	DRIVER( cps1demo )	/* Charles Doty */
	DRIVER( cps1frog )	/* Charles Doty */
	DRIVER( wofh ) 		/* 1999  Legend of Three Kingdoms' Heroes / Sanguo Yingxiong Zhuan */
	DRIVER( wofha ) 	/* 1999  Legend of Three Kingdoms' Heroes / Sanguo Yingxiong Zhuan */
	DRIVER( wof3sj )	/* 1997  Three Holy Swords / San Sheng Jian */
	DRIVER( wof3sja )	/* 1997  Three Holy Swords / San Sheng Jian */
	DRIVER( wofsj )		/* 1995  Holy Sword Three Kingdoms / Sheng Jian San Guo */
	DRIVER( wofsja )	/* 1995  Holy Sword Three Kingdoms / Sheng Jian San Guo */

	/* cps2.c */
	DRIVER( suicide )
	DRIVER( armward )

	/* dec0.c */
	DRIVER( baddudes )
	DRIVER( baddudef )	/* Arkatrad */
	DRIVER( decodemo )	/* Charles Doty */

	/* dkong.c */
	DRIVER( dkongp )	/* Fix for level 22 kill screen by Don Hodges */
	DRIVER( kong2600 )	/* Vic Twenty George hack of Donkey Kong */
	DRIVER( nadkong )
	DRIVER( dkongex )	/* Jeff's Hack with Foundry Level */
	DRIVER( dkjrhs )	/* JROK */
	DRIVER( dkonghs )	/* JROK */
	DRIVER( d2k )		/* Jumpman Returns hack */
	DRIVER( d2k11 )		/* Jumpman Returns hack */

	/* docastle.c */
	DRIVER( dcast1hs )	/* JROK */
	DRIVER( dcast2hs )	/* JROK */
	DRIVER( dcastohs )	/* JROK */
	DRIVER( sdreturn )

	/* exerion.c */
	DRIVER( exerionj )	/* Japanese version */
	DRIVER( exriongr )	/* Vag @ GreekRoms 2004 */

	/* galaga.c */
	DRIVER( galagads )	
	DRIVER( galagab2 )	
	DRIVER( galaga84 )	
	DRIVER( nebulbee )	
	DRIVER( galaga99 )	/* Jerky and Sil hack of Galaga */
	DRIVER( galagabl ) 	/* Namco 1982 version of Gallag */
	DRIVER( galagaf ) 	/* Fast Shoot Hack */
	DRIVER( galagap ) 	/* Patch to fix level 0 crash, by Don Hodges */
	DRIVER( galagix )	/* Galaga Meets Phoenix */
	DRIVER( galagost )	/* Twisty Hack of Galaga */
	DRIVER( galagosb )	/* Twisty Hack of Galaga 20021128 */
	DRIVER( galaped )	/* Cary Barnhard hack of Galaga */
	DRIVER( galgaxin )	/* T-Bone hack of Galaga */
	DRIVER( terror )	/* Galaga Terrorist Hack */
	DRIVER( galagaef )	/* Galaga Terrorist Hack */
	DRIVER( vgalaga )	/* Galaga Vector Hack */
	DRIVER( vgalagam )
	DRIVER( vgalagaf )
	DRIVER( battlesh )	/* Battles 2002 */
	DRIVER( gaous )		/* Xevious Hack */
	DRIVER( sxvioush )	/* Super Xevious 2002 */
	DRIVER( xevioush )	/* Xevious 2002 */
	DRIVER( xviousah )
	DRIVER( xeviousp )	/* Xevious Plus! */
	DRIVER( xevious3 )	/* Xevious 2003 */
	DRIVER( xevious4)	/* Xevious 2004 */
	DRIVER( xevious5)	/* Xevious 2005 */
	DRIVER( xeviblk)	/* Xevious Black */

	/* galaxian.c */
	DRIVER( amidarf )	/* ArkaMAME */
	DRIVER( amidargr )	/* GreekRoms 2004 */
	DRIVER( andromd )	/* hack - Renamed to avoid confusion with andromed (ex TestDriver) */
	DRIVER( astrians )	/* clone of Swarm */
	DRIVER( bagmanm2 )
	DRIVER( bomber )
	DRIVER( buglaxn )	/* The Dog hack of Galaxian */
	DRIVER( fourplay )
	DRIVER( froggrs )	/* bootleg */
	DRIVER( froghs )	/* JROK */
	DRIVER( galaxiab )	/* unknown hack of Galaxian */
	DRIVER( galaxkyo )	/* unknown hack of Galaxian Part X */
	DRIVER( galaxni )	/* Petaco bootleg of Galaxian Part X */
	DRIVER( galinvad )	/* T-Bone hack of Galaxian */
	DRIVER( galnamco )	/* The Original Namco */
	DRIVER( gaylaxn )	/* The Dog hack of Galaxian Part X */
	DRIVER( ghostmun )	/* From MAME 0.61 */
	DRIVER( jumpbugx )	/* jumpbug with extra sounds */
	DRIVER( kazzy )
	DRIVER( monstrz )
	DRIVER( mooncmst )
	DRIVER( mooncmwx )	/* bootleg of moon cresta */
	DRIVER( mooncrs4 )	/* Moon Crest */
	DRIVER( mooncrs5 )	/* clone of fantazia */
	DRIVER( offender )	/* Chris Henry hack of scramble */
	DRIVER( starfgh2 )	/* Bootleg of Pisces */
//	DRIVER( streakb )	/* Streaking */
	DRIVER( superdog )	/* Jerky Hack Hack of scramble */
	DRIVER( supergs )	/* Silver Systems Super Galaxian */
	DRIVER( trukker )	/* Grimlick hack of Frogger */
	DRIVER( tst_frog )	/* JROK */
	DRIVER( vectrgal )	/* T-Bone hack of Galaxian */
	DRIVER( videight )	/* 8in1 multigame */
	DRIVER( wbeast )	/* Bootleg of War-of-Bug */

	/* gaplus */
	DRIVER( gaplushs )	/* high score hack */

	/* gauntlet.c */
	DRIVER( gaunt2s )	/* Speed Hack */

	/* gottlieb.c */
	DRIVER( 711qbert )	/* Hack of Mello Yellow QBert */
	DRIVER( pbert )
	DRIVER( qbertb )	/*  */
	DRIVER( reacths )	/* JROK */
	DRIVER( vbert )

	/* invaders.c */
	DRIVER( invadsf )	/* Invaders Fast and Slow */
	DRIVER( jspectr3 )	/* clone/bootleg of jspectr2, different sized-roms */
	DRIVER( spcworld )	/* bootleg */
	DRIVER( searthie )	/* Super Earth Invasion - Electrocoin */
	DRIVER( starw1 )	/* clone of star wars */
	DRIVER( ultrainv )	/* bootleg of sicv */
	DRIVER( shuttlei )	/* (c) 197? Omori */
	DRIVER( beaminv )	/* Tekunon Kougyou */
	DRIVER( beaminva )	/* Tekunon Kougyou */
	DRIVER( rotaryf )
//	DRIVER( simg )

	/* ir.c */
	DRIVER( invrvnge )	/* Invader's Revenge */
	DRIVER( invrvnga )	/* Invader's Revenge - Dutchford*/
	DRIVER( invrvng2 )	/* Zenitone-Microsec Invader's Revenge set 2 */
	DRIVER( invrvng3 )	/* Zenitone-Microsec Game World Ltd Invader's Revenge */

	/* itech8.c */
	DRIVER( itecdemo )	/* Charles Doty */

	/* jrpacman.c */
	DRIVER( jr1000 )	/* Blue Justice */
	DRIVER( jr1000_2 )	/* Blue Justice */
	DRIVER( jr2000 )	/* Blue Justice */
	DRIVER( jr2001 )	/* Blue Justice */
	DRIVER( jr2001p )	/* Blue Justice */
	DRIVER( jr2002 )	/* Blue Justice */
	DRIVER( jr2002p )	/* Blue Justice */
	DRIVER( jr2003 )	/* Blue Justice */
	DRIVER( jr2003p )	/* Blue Justice */
	DRIVER( jr2004 )	/* Blue Justice */
	DRIVER( jr2004p )	/* Blue Justice */
	DRIVER( jr2005 )	/* Blue Justice */
	DRIVER( jr2005p )	/* Blue Justice */
	DRIVER( jr3000p )	/* Blue Justice */
	DRIVER( jr4000p )	/* Blue Justice */
	DRIVER( jr5000p )	/* Blue Justice */
	DRIVER( jr6000 )	/* Blue Justice */
	DRIVER( jr7000 )	/* Blue Justice */
	DRIVER( jr7000p )	/* Blue Justice */
	DRIVER( jr8000 )	/* Blue Justice */
	DRIVER( jr8000p )	/* Blue Justice */
	DRIVER(	jr9000p )	/* Blue Justice */
	DRIVER( jrdeluxe )	/* Blue Justice */
	DRIVER( jrhearts )
	DRIVER( jrpacad )
	DRIVER( jrpacjr )	/* Blue Justice */
	DRIVER( jrpacjrp)	/* Blue Justice */
	DRIVER( jrpacp )	/* Blue Justice */
	DRIVER( jrvectr )	/* T-Bone hack of Jr. Pac-Man */
	DRIVER( jrfast )
	DRIVER( jrcheat )
	DRIVER( jrspeed )

	/* junofrst */
	DRIVER( junohs )
	DRIVER( junohsg )

	/* mappy.c */
	DRIVER( crackhea ) 	/* Cary Barnhard hack of Mappy */
	DRIVER( housepty ) 	/* Jerky hack of Mappy */
	DRIVER( marpy )
	DRIVER( mappyhs )	/* JROK */
	DRIVER( mappyjhs )	/* JROK */
	DRIVER( supachs )	/* JROK */
	DRIVER( superpcn ) 	/* Blue Justice */
	DRIVER( superpcp )	/* Blue Justice */
	DRIVER( vectrsup )	/* T-Bone hack of Super Pac-Man */

	/* mario.c */
	DRIVER( cenmario ) 

	/* mcr.c */
	DRIVER( handiman )	/* Bobby Tribble hack of Tron */
	DRIVER( shtron )	/* Jerronimo */
	DRIVER( stapper )	/* Tapper Simpsons Hack */
	DRIVER( stapper1 )	/* Tapper Simpsons Hack ver .81 */

	/* mcr3.c */
	DRIVER( sargex )	/* Gatinho Sarge x-rated */

	/* mineswp.c */
	DRIVER( mineswp )	/* Minesweeper */

	/* midtunit.c */
	DRIVER( mkturbod )	/* MK protection hack */

	/* midwunit.c */
	DRIVER( umk3j )		/* UMK3 1.2 Juggernaut Hack v1.0 */
	DRIVER( umk3z )		/* UMK3 1.2 Zeus hack */

	/* midyunit.c */
	DRIVER( mkla4d )	/* MK protection hack */

	/* mitchell.c */
	DRIVER( armdemo )	/* Charles Doty */
	DRIVER( mitcdemo )	/* Charles Doty */

	/* monaco.c */
	DRIVER( monaco )	/* (c) 1979 SEGA*/

	/* m52.c */
	DRIVER( mranger )	/* Moon Ranger */
	DRIVER( spatrol )	/* Sponge Patrol - Gatinho 2008 */

	/* mrdo.c */
	DRIVER( mrdigdo )	/* Justin Clark hack of Mr. Do! */
	DRIVER( mrdofast )	/* Speedup hack from Evil Exidy*/
	DRIVER( mrdohs )	/* JROK */
	DRIVER( mrpac )		/* Twist Hack 20020813 */
	DRIVER( mrpacb )
	DRIVER( newdigdo )	/* Vic 20 George and Jerky hack of... */
	DRIVER( stickydo )	/* Marck's Hacks */

	/* nemesis.c */
	DRIVER( spclone )

	/* neogeo.c */

	/* mgd2 sets */

	DRIVER( bstarsd )	/* 0002 (c) 1990 SNK */
	DRIVER( tpgolfd )	/* 0003 (c) 1990 SNK */
//	DRIVER( mahretsd )	/* 0004 (c) 1990 SNK */
	DRIVER( maglordd )	/* 0005 (c) 1990 Alpha Denshi Co. */
	DRIVER( ridherod )	/* 0006 (c) 1990 SNK */
	DRIVER( alpham2d )	/* 0007 (c) 1991 SNK */
	DRIVER( ncombatd )	/* 0009 (c) 1990 Alpha Denshi Co. */
	DRIVER( cyberlid )	/* 0010 (c) 1990 SNK */
	DRIVER( superspd )	/* 0011 (c) 1990 SNK */
	DRIVER( mutnatd )	/* 0014 (c) 1992 SNK */
	DRIVER( kotmd )		/* 0016 (c) 1991 SNK */
	DRIVER( sengokud )	/* 0017 (c) 1991 SNK */
	DRIVER( burningd )	/* 0018 (c) 1991 SNK */
	DRIVER( lbowlind )	/* 0019 (c) 1990 SNK */
	DRIVER( gpilotsd )	/* 0020 (c) 1991 SNK */
	DRIVER( joyjoyd )	/* 0021 (c) 1990 SNK */
//	DRIVER( bjourned )	/* 0022 (c) 1990 Alpha Denshi Co. */
//	DRIVER( quizdaid )	/* 0023 (c) 1991 SNK */
	DRIVER( lresortd )	/* 0024 (c) 1992 SNK */
	DRIVER( eightmad )	/* 0025 (c) 1991 SNK / Pallas */
	DRIVER( minasand )	/* 0027 (c) 1990 Monolith Corp. */
//	DRIVER( legendod )	/* 0029 (c) 1991 SNK */
	DRIVER( 2020bbd )	/* 0030 (c) 1991 SNK / Pallas */
	DRIVER( socbrawd )	/* 0031 (c) 1991 SNK */
	DRIVER( roboarmd )	/* 0032 (c) 1991 SNK */
	DRIVER( fatfuryd )	/* 0033 (c) 1991 SNK */
	DRIVER( fbfrenzd )	/* 0034 (c) 1992 SNK */
	DRIVER( bakatond )	/* 0036 (c) 1991 Monolith Corp. */
	DRIVER( crswordd )	/* 0037 (c) 1991 Alpha Denshi Co. */
	DRIVER( trallyd )	/* 0038 (c) 1991 Alpha Denshi Co. */
//	DRIVER( kotm2d )	/* 0039 (c) 1992 SNK */
	DRIVER( sengok2d )	/* 0040 (c) 1993 SNK */
//	DRIVER( bstars2d )	/* 0041 (c) 1992 SNK */
//	DRIVER( quizda2d )	/* 0042 (c) 1992 SNK */
	DRIVER( 3countbd )	/* 0043 (c) 1993 SNK */
	DRIVER( aofd )		/* 0044 (c) 1992 SNK */
//	DRIVER( samshod )	/* 0045 (c) 1993 SNK */
//	DRIVER( tophuntd )	/* 0046 (c) 1994 SNK */
//	DRIVER( fatfry2d )	/* 0047 (c) 1992 SNK */
//	DRIVER( janshind )	/* 0048 (c) 1994 Aicom */
	DRIVER( androdud )	/* 0049 (c) 1992 Visco */
	DRIVER( ncommndd )	/* 0050 (c) 1992 Alpha Denshi Co. */
//	DRIVER( viewpoid )	/* 0051 (c) 1992 Sammy */
//	DRIVER( ssidekid )	/* 0052 (c) 1992 SNK */
	DRIVER( wh1d )		/* 0053 (c) 1992 Alpha Denshi Co. */

	/* decrypted sets */

	DRIVER( ganryud )
	DRIVER( garoud )
	DRIVER( kof99d )
	DRIVER( kof2000d )
	DRIVER( kof2001d )
	DRIVER( kof2002d )
	DRIVER( matrimd )
	DRIVER( mslug3d )
	DRIVER( mslug4d )
	DRIVER( mslug5d )
	DRIVER( nitdd )
	DRIVER( preisl2d )
	DRIVER( rotdd )
	DRIVER( s1945pd )
	DRIVER( samsh5sd )
	DRIVER( samsho5d )
	DRIVER( sengok3d )
	DRIVER( svcd )
	DRIVER( zupapad )
	/* homebrew */
//	DRIVER( beast )		/* 2002 (c) 1989 Psygnosis */
	DRIVER( cndi )		/* Chip n Dale Intro */
	DRIVER( cnbe )
	DRIVER( columnsn )	/* 2000 (c) 1990 Sega */
	DRIVER( dwi )		/* DarkWing Duck Intro */
	DRIVER( frogfest )
	DRIVER( gbi )		/* Ghostbusters Intro */
	DRIVER( lhcdb )		/* 2007 (c) Last Hope CD beta */
	DRIVER( ltorb )
	DRIVER( neodemo )	/* Charles Doty */
//	DRIVER( neopong )	/* xxxx (c) 2002 Neodev - removed - not working */
	DRIVER( ngem2k )
//	DRIVER( npong10 )	/* xxxx (c) 2002 Neodev - removed - not working */
	DRIVER( neonopon )	/* xxxx (c) 2002 Blastar */
	DRIVER( neo2500 )	/* Blastar */
	DRIVER( poknight )	/* 2003 (c) 200? JMK */
	DRIVER( rci )		/* Robocop intro */
	DRIVER( smi )		/* Spiderman intro */
	DRIVER( syscheck )
	DRIVER( tmnti )		/* TMNT intro */
	/* prototype - bootleg - from CD */
	DRIVER( bangbedp )	/* 2000 Visco - Prototype ? */
	DRIVER( kof96ep )
	DRIVER( kf2k1pls )
	DRIVER( kf2k1pa )
	DRIVER( kf2k2plb )
	DRIVER( pbobblnb )
	DRIVER( pbobbldx )
	DRIVER( zintrkcd )	/* 0211 (c) 1996 ADK / SNK */
	DRIVER( fr2cd )		/* 0098 (c) 1995 Video Systems Co. */
	DRIVER( fr2ch )		/* 0098 (c) 1995 Video Systems Co. */
	/* translation */
	DRIVER( fightfek )
	DRIVER( flipshok )
	DRIVER( kof98fr )	/* Neo-Arc French Trans */
	DRIVER( kof98fro )	/* Neo-Arc French Trans */
	DRIVER( kf98fro2 )	/* Neo-Arc French Trans */
	DRIVER( kof2k2br )
	DRIVER( kf2k2br1 )
	DRIVER( kf2k2br2 )
	DRIVER( mdrop3fr )	/* Neo-Arc French Trans */
	DRIVER( miexchfr )	/* Neo-Arc French Trans */
	DRIVER( mslugxfr )	/* Neo-Arc French Trans */
	DRIVER( mslgxfro )	/* Neo-Arc French Trans */
	DRIVER( mslugxit )
	DRIVER( mslug2fr )	/* Neo-Arc French Trans */
	DRIVER( mslg2fro )	/* Neo-Arc French Trans */
	DRIVER( mslug3fr )	/* Neo-Arc French Trans */
	DRIVER( mslg3fro )	/* Neo-Arc French Trans */
	DRIVER( mslug4fr )	/* Neo-Arc French Trans */
	DRIVER( mslug5fr )	/* Neo-Arc French Trans */
	DRIVER( necup98k )
	DRIVER( nitdfr )	/* Neo-Arc French Trans */
	DRIVER( nitdfro )	/* Neo-Arc French Trans */
	DRIVER( nitdsp )
	DRIVER( rotdbr )
	DRIVER( rotdbr1 )
	DRIVER( rotdbr2 )
	DRIVER( wjammerk )
	/* other hacks */
	DRIVER( aof2b )
	DRIVER( aof2br2 )
	DRIVER( aof3b )
	DRIVER( breaksp )	
	DRIVER( cthd2k3b )
	DRIVER( ct2k3eh )
	DRIVER( ct2k3k3 )
	DRIVER( ct2k3k3o )
	DRIVER( dbdehy )
	DRIVER( dbdy )
	DRIVER( dbdeh )
	DRIVER( dbdq )
	DRIVER( dbdqb )
	DRIVER( dbdqp )
	DRIVER( dbdqeh )
	DRIVER( ffur3b )
	DRIVER( ffur3bd )
	DRIVER( ffur3eh )
	DRIVER( ffspeh )
	DRIVER( garopamu )
	DRIVER( garoupeh )
	DRIVER( garopehc )
	DRIVER( garoupy )
	DRIVER( garoupf )
	DRIVER( garoupfu )
	DRIVER( garoupfp )
	DRIVER( ironclad )	/* 1996 Saurus */
	DRIVER( ironcld1 )	/* 1996 Saurus */
	DRIVER( joyjoycd )
	DRIVER( kabukleh )
	DRIVER( kabuklyc )
	DRIVER( kabukgmc )
	DRIVER( kabuklgm )
	DRIVER( kabuklmc )
	DRIVER( karnvreh )
	DRIVER( kizunaeh )
	DRIVER( kof94b )
	DRIVER( kof94seh )
	DRIVER( kof94eh )
	DRIVER( kof94ru )
	DRIVER( kof95b )
	DRIVER( kof95seh )
	DRIVER( kof95eh )
	DRIVER( kof95hp )
	DRIVER( kof95pjc )
	DRIVER( kof95ru )
	DRIVER( kof95y )
	DRIVER( kof96b )
	DRIVER( kof96c )
	DRIVER( kf96ckvs )
	DRIVER( kof96cr )
	DRIVER( kof96chj )
	DRIVER( kof96seh )
	DRIVER( kof96eh )
	DRIVER( kof96evo )
	DRIVER( kf96evoo )
	DRIVER( kof96ey )
	DRIVER( kof96hp )
	DRIVER( kof96hpr )
	DRIVER( kof96k )
	DRIVER( kof96k3 )
	DRIVER( kof96k3o )
	DRIVER( kof96pjc )
	DRIVER( kof96rcw )
	DRIVER( kof96ri )
	DRIVER( kof96ri1 )
	DRIVER( kof96ri2 )
	DRIVER( kof96ri3 )
	DRIVER( kof96ri4 )
	DRIVER( kof96ri5 )
	DRIVER( kof96ru )
	DRIVER( kof96rw )
	DRIVER( kof97bh )
	DRIVER( kof97cr )
	DRIVER( kof97chl )
	DRIVER( kf97chl2 )
	DRIVER( kof97eh )
	DRIVER( kof97eh2 )
	DRIVER( kof97eho )
	DRIVER( kof97hxd )
	DRIVER( kof97ice )
	DRIVER( kof97kp )
	DRIVER( kof97lc )
	DRIVER( kof97lr )
	DRIVER( kof97mit )
	DRIVER( kof97ne )
	DRIVER( kof97pj )
	DRIVER( kof97pjc )
	DRIVER( kof97sw )
	DRIVER( kof97saw )
	DRIVER( kof97wh )
	DRIVER( kf97wpls )
	DRIVER( kof97xp )
	DRIVER( kof97y )
	DRIVER( kof97ya )
	DRIVER( kof97yb )
	DRIVER( kof97ye )
	DRIVER( kof97yg )
	DRIVER( kof97yh )
	DRIVER( kof97yk )
	DRIVER( kof97yl )
	DRIVER( kof97yl2 )
	DRIVER( kof98cd )
	DRIVER( kof98ch )
	DRIVER( kof98chl )
	DRIVER( kof98co )
	DRIVER( kof98dc )
	DRIVER( kof98ehr )
	DRIVER( kof98ice )
	DRIVER( kof98ico )
	DRIVER( kof98jh )
	DRIVER( kof98pjc )
	DRIVER( kof98rh )
	DRIVER( kof98rm )
	DRIVER( kof98seh )
	DRIVER( kf98seho )
	DRIVER( kof98wh )
	DRIVER( kof98wh2 )
	DRIVER( kof98y )
	DRIVER( kof98yh )
	DRIVER( kof99ab )
	DRIVER( kof99bh )
	DRIVER( kof99ch )
	DRIVER( kof99chf )
	DRIVER( kof99fc )
	DRIVER( kof99seh )
	DRIVER( kof99eh )
	DRIVER( kof99jh )
	DRIVER( kof99jho )
	DRIVER( kof99lb )
	DRIVER( kof99m )
	DRIVER( kof99pt )
	DRIVER( kof99rpp )
	DRIVER( kof99rp )
	DRIVER( kof99rp1 )
	DRIVER( kof99rp2 )
	DRIVER( kof99rp3 )
	DRIVER( kof99rp4 )
	DRIVER( kof99rp5 )
	DRIVER( kof99rp6 )
	DRIVER( kof99rp7 )
	DRIVER( kof99rp8 )
	DRIVER( kof99rp9 )
	DRIVER( kof99rpa )
	DRIVER( kof99rpb )
	DRIVER( kof99rpc )
	DRIVER( kof99r )
	DRIVER( kof99btr )
	DRIVER( kof99ehr )
	DRIVER( kof99rr )
	DRIVER( kof99sp )
	DRIVER( kof99y )
	DRIVER( kof99yd )	
	DRIVER( kf99pjc1 )
	DRIVER( kf99pjc2 )
	DRIVER( kf99pjc3 )
	DRIVER( kf99pjco )
	DRIVER( kof99hp )
	DRIVER( kof99kp )
	DRIVER( kof99pk )
	DRIVER( kof99pko )
	DRIVER( kof99pm )
	DRIVER( kof99py )
	DRIVER( kf99revo )
	DRIVER( kof99rs )
	DRIVER( kof99rsm )
	DRIVER( kof99rsp )
	DRIVER( kof99wh1 )
	DRIVER( kof99wh2 )
	DRIVER( kof99wh3 )
	DRIVER( kof99wh4 )
	DRIVER( kf99xpsf )
	DRIVER( kf99xpsp )
	DRIVER( kf99xpsa )
	DRIVER( kof99yb )
	DRIVER( kof2kbh )
	DRIVER( kof2kbj )
	DRIVER( kof2kce )
	DRIVER( kof2kch )
	DRIVER( kof2kcp )
	DRIVER( kof2kseh )
	DRIVER( kof2keh )
	DRIVER( kof2kevo )
	DRIVER( kf2kevo1 )
	DRIVER( kf2kevo2 )
	DRIVER( kof2kgbh )
	DRIVER( kf2kgold )
	DRIVER( kof2kice )
	DRIVER( kof2kjlc )
	DRIVER( kof2kkf1 )
	DRIVER( kof2kkvs )
	DRIVER( kof2kkzs )
	DRIVER( kof2kpjc )
	DRIVER( kf2kpjc1 )
	DRIVER( kf2kpjc2 )
	DRIVER( kf2kpjc3 )
	DRIVER( kof2krm )
	DRIVER( kof2kehr )
	DRIVER( kof2krp )
	DRIVER( kof2kst )
	DRIVER( kof2kwh )
	DRIVER( kof2kwh2 )
	DRIVER( kof2ky )
	DRIVER( kof2kyd )
	DRIVER( kof2kyg )
	DRIVER( kof2kz )
	DRIVER( kof2kzs )
	DRIVER( kof2k1ay )
	DRIVER( kof2k1b3 )
	DRIVER( kof2k1cr )
	DRIVER( kf2k1seh )
	DRIVER( kf2k1ehc )
	DRIVER( kof2k1eh )
	DRIVER( kof2k1hb )
	DRIVER( kf2k1mk2 )
	DRIVER( kof2k1mk )
	DRIVER( kf2k1mke )
	DRIVER( kof2k1rm )
	DRIVER( kf2k1ehr )
	DRIVER( kof2k1b )
	DRIVER( kf2k1bd2 )
	DRIVER( kof2k1bh )
	DRIVER( kof2k1ce )
	DRIVER( kf2k1cfc )
	DRIVER( kf2k1cf1 )
	DRIVER( kof2k1ch )
	DRIVER( kf2k1clr )
	DRIVER( kof2k1cp )
	DRIVER( kf2k1cp1 )
	DRIVER( kf2k1cp2 )
	DRIVER( kf2k1cp3 )
	DRIVER( kf2k1cp4 )
	DRIVER( kf2k1cp5 )
	DRIVER( kf2k1cp6 )
	DRIVER( kf2k1cp7 )
	DRIVER( kof2k1gm )
	DRIVER( kf2k1hgm )
	DRIVER( kof2k1ha )
	DRIVER( kf2k1ha2 )
	DRIVER( kf2k1hao )
	DRIVER( kf2k1k3o )
	DRIVER( kf2k1k32 )
	DRIVER( kf2k1k33 )
	DRIVER( kf2k1k34 )
	DRIVER( kf2k1k35 )
	DRIVER( kf2k1k36 )
	DRIVER( kf2k1k37 )
	DRIVER( kf2k1k38 )
	DRIVER( kf2k1k39 )
	DRIVER( kf2k1k3a )
	DRIVER( kf2k1k3b )
	DRIVER( kf2k1k3c )
	DRIVER( kf2k1k3d )
	DRIVER( kf2k1k3e )
	DRIVER( kf2k1k3f )
	DRIVER( kf2k1k3g )
	DRIVER( kf2k1k3h )
	DRIVER( kf2k1ice )
	DRIVER( kf2k1ic2 )
	DRIVER( kf2k1lse )
	DRIVER( kf2k1pjc )
	DRIVER( kf2k1pjo )
	DRIVER( kf2k1pj1 )
	DRIVER( kf2k1pj2 )
	DRIVER( kf2k1pj3 )
	DRIVER( kof2k1rp )
	DRIVER( kf2k1rpo )
	DRIVER( kf2k1rp1 )
	DRIVER( kof2k1ru )
	DRIVER( kf2k1sob )
	DRIVER( kof2k1wh )
	DRIVER( kof2k1z1 )
	DRIVER( kof2k1z2 )
	DRIVER( kof2k2b )
	DRIVER( kof2k2b1 )
	DRIVER( kof2k2bh )
	DRIVER( kf2k2bjh )
	DRIVER( kf2k2bjo )
	DRIVER( kf2k2cfc )
	DRIVER( kf2k2cf1 )
	DRIVER( kf2k2cf2 )
	DRIVER( kf2k2cf3 )
	DRIVER( kof2k2ch )
	DRIVER( kf2k2chl )
	DRIVER( kf2k2cl2 )
	DRIVER( kf2k2cl3 )
	DRIVER( kf2k2dbh )
	DRIVER( kof2k2e1 )
	DRIVER( kof2k2e2 )
	DRIVER( kof2k2e3 )
	DRIVER( kf2k2ehr )
	DRIVER( kf2k2er2 )
	DRIVER( kf2k2er3 )
	DRIVER( kf2k2er4 )
	DRIVER( kf2k2erx )
	DRIVER( kf2k2evo )
	DRIVER( kf2k2seh )
	DRIVER( kf2k2se2 )
	DRIVER( kof2k2fy )
	DRIVER( kof2k2gc )
	DRIVER( kf2k2gc2 )
	DRIVER( kof2k2gf )
	DRIVER( kf2k2ice )
	DRIVER( kf2k2ic1 )
	DRIVER( kf2k2ic2 )
	DRIVER( kof2k2jc )
	DRIVER( kof2k2kc )
	DRIVER( kf2k2k3o )
	DRIVER( kf2k2k32 )
	DRIVER( kf2k2k33 )
	DRIVER( kf2k2k34 )
	DRIVER( kf2k2k35 )
	DRIVER( kf2k2k36 )
	DRIVER( kf2k2k37 )
	DRIVER( kf2k2k38 )
	DRIVER( kf2k2k39 )
	DRIVER( kf2k2k3a )
	DRIVER( kf2k2k3b )
	DRIVER( kf2k2k3c )
	DRIVER( kf2k2k3d )
	DRIVER( kf2k2k3e )
	DRIVER( kf2k2k3f )
	DRIVER( kf2k2k3g )
	DRIVER( kf2k2ori )
	DRIVER( kf2k2pjw )
	DRIVER( kof2k2pr )
	DRIVER( kf2k2pro )
	DRIVER( kof2k2ra )
	DRIVER( kof2k2rm )
	DRIVER( kf2k2rm1 )
	DRIVER( kf2k2rm2 )
	DRIVER( kf2k2rm3 )
	DRIVER( kof2k2rr )
	DRIVER( kf2k2rr1 )
	DRIVER( kf2k2rr2 )
	DRIVER( kf2k2rr3 )
	DRIVER( kf2k2rr4 )
	DRIVER( kf2k2rr5 )
	DRIVER( kf2k2rr6 )
	DRIVER( kf2k2rr7 )
	DRIVER( kf2k2rr8 )
	DRIVER( kof2k2rs )
	DRIVER( kof2k2ru )
	DRIVER( kf2k2ru )
	DRIVER( kof2k2rw )
	DRIVER( kof2k2sb )
	DRIVER( kof2k2sp )
	DRIVER( kf2k2spo )
	DRIVER( kof2k2tc )
	DRIVER( kof2k2ul )
	DRIVER( kf2k2ule )
	DRIVER( kf2k2wuk )
	DRIVER( kf2k2xxx )
	DRIVER( kof2k3b )
	DRIVER( kof2k3gc )
	DRIVER( kof2k3sc )
	DRIVER( kof2k3tc )
	DRIVER( kf2k3zgf )
	DRIVER( labld2pl )
	DRIVER( lastbl2b )
	DRIVER( lastbldb )
	DRIVER( lastblde )
	DRIVER( lbboss )
	DRIVER( lbeh )
	DRIVER( lbeh2 )
	DRIVER( lbseh )
	DRIVER( lbeho )
	DRIVER( lby )
	DRIVER( lb2a )
	DRIVER( lb2bhd )
	DRIVER( lb2easy )
	DRIVER( lb2ed )
	DRIVER( lb2ebd )
	DRIVER( lb2eh )
	DRIVER( lb2eh2 )
	DRIVER( lb2eho )
	DRIVER( lb2ehu )
	DRIVER( lb2wh )
	DRIVER( lb2yd )
	DRIVER( mslugeh )
	DRIVER( mslugxeh )
	DRIVER( mslug2eh )
	DRIVER( mslg2eh1 )
	DRIVER( mslg2eh2 )
	DRIVER( mslg2eh3 )
	DRIVER( mslg2eh4 )
	DRIVER( mslg3eha )
	DRIVER( mslg3ehs )
	DRIVER( mslg3e02 )
	DRIVER( mslg3e03 )
	DRIVER( mslg3e04 )
	DRIVER( mslg3e05 )
	DRIVER( mslg3e06 )
	DRIVER( mslg3e07 )
	DRIVER( mslg3e08 )
	DRIVER( mslg3e09 )
	DRIVER( mslg3e10 )
	DRIVER( mslg3e11 )
	DRIVER( mslg3e12 )
	DRIVER( mslg3e13 )
	DRIVER( mslg3e14 )
	DRIVER( mslg3e15 )
	DRIVER( mslg3e16 )
	DRIVER( mslg3e17 )
	DRIVER( mslg3e18 )
	DRIVER( mslg3e19 )
	DRIVER( mslg3e20 )
	DRIVER( mslg3e21 )
	DRIVER( mslg3e22 )
	DRIVER( mslug3kh )
	DRIVER( mslg3kho )
	DRIVER( mslug4eh )
	DRIVER( mslg4eh2 )
	DRIVER( mslg4eh3 )
	DRIVER( mslg4eh4 )
	DRIVER( mslg4eh5 )
	DRIVER( mslg4eh6 )
	DRIVER( mslg4eho )
	DRIVER( mslug4i )
	DRIVER( mslug4kh )
	DRIVER( nam1975g )
	DRIVER( nam1975h )
	DRIVER( ngfrog )
	DRIVER( njmeh )
	DRIVER( njmehc )
	DRIVER( njmehyc )
	DRIVER( matrmehc )
	DRIVER( rbff1ud )
	DRIVER( rbffsehd )
	DRIVER( rbffsb )
	DRIVER( rbffseh )
	DRIVER( rbffspy )
	DRIVER( rbffsud )
	DRIVER( rbff2b )
	DRIVER( rbff2bh )
	DRIVER( rbff2eh )
	DRIVER( rbff2ehc )
	DRIVER( rbff2eh2 )
	DRIVER( rbff2eho )
	DRIVER( rbff2fc )
	DRIVER( rbff2ud )
	DRIVER( rbff2y )
	DRIVER( rageh )
	DRIVER( rotdb )
	DRIVER( rotdeh )
	DRIVER( rotdehc )
	DRIVER( rotdcre )
	DRIVER( rotdcreb )
	DRIVER( rotdh2b )
	DRIVER( rotdhab )
	DRIVER( rotdhar )
	DRIVER( rotdhfw )
	DRIVER( rotdhfwb )
	DRIVER( rotdfw )
	DRIVER( rotdfy )
	DRIVER( rotdyc )
	DRIVER( s1945pwe )
	DRIVER( samshob )
	DRIVER( samshoeh )
	DRIVER( samsheh2 )
	DRIVER( samsh2eh )
	DRIVER( samsh2yc )
	DRIVER( samsh3eh )
	DRIVER( samsh3yc )
	DRIVER( samsh3se )
	DRIVER( samsh4bh )
	DRIVER( samsh4cz )
	DRIVER( samsh4eh )
	DRIVER( samsh4es )
	DRIVER( samsh4ew )
	DRIVER( samsh4fc )
	DRIVER( samsh4kw )
	DRIVER( samsh4kz )
	DRIVER( samsh4wh )
	DRIVER( savagedb )
	DRIVER( senkucd )
	DRIVER( senku3kc )
	DRIVER( senku3k )
	DRIVER( senku3c )
	DRIVER( senku3b )
	DRIVER( senku3ha )
	DRIVER( senku3yk )
	DRIVER( senku3ya )
	DRIVER( shockt2w )
	DRIVER( tpgolfcd )
	DRIVER( viewpntr )
	DRIVER( wakuw7bh )
	DRIVER( wh2ey )
	DRIVER( whpb )
	DRIVER( whpb2 )
	DRIVER( whpbh )
	DRIVER( whpbho )
	DRIVER( whpbho2)
	DRIVER( whpeh )
	DRIVER( whpeho )

	/* pacland.c */
	DRIVER( mariopac )
	DRIVER( paclandb )
	DRIVER( paclandd )	/* Blue Justice */

	/* pacman.c */
	DRIVER( abortman ) 	/* Paul C Copeland hack of Puckman */
	DRIVER( absurd )	/* scott - nonworking alpha ver 3 */
	DRIVER( baby2 )		/* T-Bone hack */
	DRIVER( baby3 )		/* T-Bone hack */
	DRIVER( baby4 )		/* T-Bone hack */
	DRIVER( brakman )	/* Jerry Lawrence hack of Pac-Man (Midway) */
	DRIVER( bucaneer )	/* PacMAME Hacks */
	DRIVER( caterpil )
	DRIVER( chtmsatk )	/* PacMAME Hacks */
	DRIVER( chtmspa )	/* PacMAME Hacks */
	DRIVER( chtpac )
	DRIVER( chtpac3d )
	DRIVER( chtpman2 )
	DRIVER( chtpop )
	DRIVER( chtpuck )
	DRIVER( cookiem )
	DRIVER( crashh )	/* PacMAME Hacks */
	DRIVER( crazypac )
	DRIVER( dizzy )
	DRIVER( eltonpac )	/* Sil hack of Pac-Man (Midway) */
	DRIVER( europac )	/* Stefano 'Jojo' Priore hack of Pac-Man (Midway) */
	DRIVER( eyesb )
//	DRIVER( eyesb2 )	// looks same as eyesb, so removed in 0.128.B
	DRIVER( fasthear )	/* PacMAME Hacks */
	DRIVER( fastmspa )	/* PacMAME Hacks */
	DRIVER( faststrm )	/* PacMAME Hacks */
	DRIVER( fpnleash )
	DRIVER( fstmsatk )	/* PacMAME Hacks */
	DRIVER( hanglyad )
	DRIVER( hmhearts )	/* hack */
	DRIVER( heartbn2 )	/* PacMAME Hacks */
	DRIVER( heartbrn )	/* unknown hack of Ms. Pac-Man */
	DRIVER( hearts )
	DRIVER( hm1000 )	/* Blue Justice */
	DRIVER( hm2000 )	/* Blue Justice */
	DRIVER( hmba5000 )	/* Blue Justice */
	DRIVER( hmba7000 )	/* Blue Justice */
	DRIVER( hmbabymz )	/* Blue Justice */
	DRIVER( hmbluep )	/* Blue Justice */
	DRIVER( hmgrenp )	/* Blue Justice */
	DRIVER( hmpopey )	/*  */
	DRIVER( hmplus )	/* Blue Justice */
	DRIVER( homercid )	/* David Widel */
	DRIVER( jacman )
	DRIVER( jpmmunch )	/* JPM bootleg */
	DRIVER( mazeman )	/* Sil hack of Pac-Man */
	DRIVER( mrpacman )
	DRIVER( ms1000 )	/* Blue Justice */
	DRIVER( ms2000 )	/* Blue Justice */
	DRIVER( ms2600 )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( ms3000 )	/* Blue Justice */
	DRIVER( ms4000p )	/* Blue Justice */
	DRIVER( mspaceur )
//	DRIVER( ms4in1 )
	DRIVER( ms5000 )	/* Blue Justice */
	DRIVER( ms5000p )	/* Blue Justice */
	DRIVER( msatk2ad )	/* PacMAME Hacks */
	DRIVER( msatkad )
	DRIVER( msbaby )	/* T-Bone hack */
	DRIVER( msberzk )	/* Bobby Tribble hack of Ms. Pac-Man */
	DRIVER( mscrzyma )	/* Blue Justice */
	DRIVER( mscrzymp )	/* Blue Justice */
	DRIVER( msdroid )	/* Grendal74 */
	DRIVER( msdstorm )	/* Mike Naylor hack of Ms. Pac-Man */
	DRIVER( mselton )	/* Sil hack of Ms. Pac-Man */
	DRIVER( msextra )	/* Blue Justice */
	DRIVER( msextrap )	/* Blue Justice */
	DRIVER( msf1pac )	/* Sil hack of Ms. Pac-Man */
	DRIVER( msgrkatk )	/* Grendal74 */
	DRIVER( msgrkb )	/* Grendal74 */
	DRIVER( mshangly )	/* PacMAME Hacks */
	DRIVER( mshearts )	/* PacMAME Hacks */
	DRIVER( msheartb )
	DRIVER( msindy )	/* Sil hack of Ms. Pac-Man */
	DRIVER( msmini )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msminia )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msmspac )	/* Blue Justice */
//	DRIVER( msnapco )	/* Ms. Pac-Man with Eyes encryption */
	DRIVER( msnes4a )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msnes62 )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msnes63 )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msnes6m )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msnes6m2 )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msnes6m3 )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msnes6m4 )	/* T-Bone hack of Ms. Pac-Man */
//	DRIVER( mspac1 )	/* from Greekmame 0.87 */
	DRIVER( mspac6m )	/* Sil hack of Ms. Pac-Man */
	DRIVER( mspac6m2 )	/* Sil hack of Ms. Pac-Man (fixed) */
	DRIVER( mspacad )	/* Sil hack of Ms. Pac-Man */
	DRIVER( mspacat2 )	/* Sil hack of Miss Pac Plus */
	DRIVER( mspacatb )
//	DRIVER( mspacde )
	DRIVER( mspacdel )	/* Blue Justice */
	DRIVER( mspacit )
//	DRIVER( mspacit2 )
	DRIVER( mspacmap )	/* Don Hodges patch to fix various bugs in mspacmab */
//	DRIVER( mspacmbg )
	DRIVER( mspacnes )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( mspacp )	/* Blue Justice */
	DRIVER( mspacpbl )	/* Dav/PMP bootleg */
	DRIVER( mspacren )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( mspacrip )	/* R3mer hack of Ms. Pac-Man */
	DRIVER( mspacsup )	/* Super Ms. Pac-Man */
	DRIVER( mspamsba )	/* Blue Justice */
	DRIVER( mspc6mad )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msplus )	/* Blue Justice 20010824 */
	DRIVER( msrumble )
	DRIVER( mssilad )	/* PacMAME Hacks */
	DRIVER( msstrmaz )	/* Blue Justice */
	DRIVER( msultra )
	DRIVER( msvctr6m )	/* T-Bone hack of Ms. Pac-Man */
	DRIVER( msvectr )	/* PacMAME Hacks */
	DRIVER( msyakman )	/* PacMAME Hacks */
	DRIVER( namcosil )	/* Sil hack of Pac-Man (Namco) */
	DRIVER( newpuck2 )	/* Scotty hack of Pac-Man */
	DRIVER( newpuck3 )
	DRIVER( nmousea )
	DRIVER( nwpuc2b )
	DRIVER( pac2600 )	/* Bobby Tribble hack of Pac-Man (Midway) */
	DRIVER( pac2600a )
	DRIVER( pacatk )	/* Widel's Games */
	DRIVER( pacbaby )
	DRIVER( pacbaby2 )
	DRIVER( pacbaby3 )
	DRIVER( pacbell )
	DRIVER( pacelec )
	DRIVER( pacgent )
	DRIVER( pacinvis )
	DRIVER( pacjail )
	DRIVER( pacjr1 )
	DRIVER( pacjr2 )
	DRIVER( pacjr3 )
	DRIVER( pacjr4 )
	DRIVER( pacm255 )	/* Mark Spaeth patch for level 256 */
	DRIVER( pacman3d )	/* Sil hack of Pac-Man (Midway) */
	DRIVER( pacman6 )
	DRIVER( pacmanp )	/* Don Hodges patch for level 256 */
	DRIVER( pacmar )	/* PacMAME Hacks */
	DRIVER( pacmini )	/* Bobby Tribble hack of Pac-Man (Midway) */
	DRIVER( pacmini2 )	/* Bobby Tribble hack of Pac-Man (Midway) */
	DRIVER( pacmn6m2 )
	DRIVER( pacms1 )
	DRIVER( pacms2 )
	DRIVER( pacms3 )
	DRIVER( pacms4 )
	DRIVER( pacmsa1 )
	DRIVER( pacmsa2 )
	DRIVER( pacmsa3 )
	DRIVER( pacmsa4 )
	DRIVER( pacmulti )
	DRIVER( puck255 )
	DRIVER( pacplusc )
	DRIVER( pacpopey )	/* unknown hack of Pac-Man (Namco) */
	DRIVER( pacshuf )
	DRIVER( pacspeed )
	DRIVER( pacweird )
	DRIVER( pcrunchy )
	DRIVER( pengman )	/* Jerry Lawrence hack of Pac-Man (Midway) */
	DRIVER( pengopac )
	DRIVER( petshop )
	DRIVER( piranha2 )
	DRIVER( pm1000 )	/* Blue Justice */
	DRIVER( pm2000 )	/* Blue Justice */
	DRIVER( pm3000 )	/* Blue Justice */
	DRIVER( pm4000p )	/* Blue Justice */
	DRIVER( pm5000p )	/* Blue Justice */
	DRIVER( pm6000 )	/* Blue Justice */
	DRIVER( pm7000 )	/* Blue Justice */
	DRIVER( pm7000p )	/* Blue Justice */
	DRIVER( pmad )		/* SirScotty and Sil hack of Pac-Man (Midway) */
	DRIVER( pmad00 )
	DRIVER( pmad6m )	/* T-Bone hack */
	DRIVER( pmada )
	DRIVER( pmba2000 )	/* Blue Justice */
	DRIVER( pmba3000 )	/* Blue Justice */
	DRIVER( pmba4000 )	/* Blue Justice */
	DRIVER( pmba6000 )	/* Blue Justice */
	DRIVER( pmba8000 )	/* Blue Justice */
	DRIVER( pmbamaz )	/* Blue Justice */
	DRIVER( pmbaplus )	/* Blue Justice */
	DRIVER( pmbluep )	/* Blue Justice */
	DRIVER( pmdeluxe )	/* Blue Justice */
	DRIVER( pmextra )	/* Blue Justice */
	DRIVER( pmextrap )	/* Blue Justice */
	DRIVER( pmfever )	/* Blue Justice */
	DRIVER( pmgrenp )	/* Blue Justice */
	DRIVER( pmheart )
	DRIVER( newpuc1 )	/* Italian dump */
	DRIVER( pplusad )
	DRIVER( puckman )	/* (c) 1980 Namco */
	DRIVER( puckmano )
	DRIVER( puckmoti )
	DRIVER( puckmot1 )
	DRIVER( puckren )
	DRIVER( puckrenc )
	DRIVER( punleash )
	DRIVER( roboman )
	DRIVER( snakeyes )	/* T-Bone hack */
	DRIVER( snowpac )	/* T-Bone hack */
	DRIVER( spuckman )
	DRIVER( sueworlb )
	DRIVER( sueworld )
	DRIVER( sumeltob )
	DRIVER( sumelton )
	DRIVER( superabc )
	DRIVER( supmspac )	/* Spedic Vending bootleg */
	DRIVER( tbone )		/* T-Bone hack */
	DRIVER( ultra2 )	/* PacMAME Hacks */
	DRIVER( ultrapac )
	DRIVER( vcrunchy )
	DRIVER( vecbaby )
	DRIVER( vecbaby2 )
	DRIVER( vecbaby3 )
	DRIVER( vecpac )	/* T-Bone hack of Pac-Man (Midway) */
	DRIVER( vectplus )
	DRIVER( vectr6m )	/* T-Bone hack */
	DRIVER( vectr6tb )	/* T-Bone hack */
	DRIVER( vectratk )	/* Sil and T-Bone hack of Ms. Pac-Man */
	DRIVER( vectxens )
	DRIVER( vhangly )
	DRIVER( vhangly3 )
	DRIVER( vpacbell )
	DRIVER( vpacelec )
	DRIVER( vpacjail )
	DRIVER( vpacms1 )
	DRIVER( vpacms2 )
	DRIVER( vpacms3 )
	DRIVER( vpacms4 )
	DRIVER( vpacmsa1 )
	DRIVER( vpacmsa2 )
	DRIVER( vpacmsa3 )
	DRIVER( vpacmsa4 )
	DRIVER( vpacshuf )
	DRIVER( vpspeed )
	DRIVER( xensad )
	DRIVER( xensrev )
	DRIVER( multi10 )	/* bootleg */
	DRIVER( multi11 )	/* bootleg */
	DRIVER( multi13 )	/* bootleg */
	DRIVER( multi14 )	/* bootleg */
	DRIVER( multi15 )	/* bootleg */
	DRIVER( 96in1 )		/* Widel's Games */
	DRIVER( 96in1a )	/* Widel's Games */
	DRIVER( 96in1b )	/* Widel's Games */
	DRIVER( 96in1c )	/* Widel's Games */
	DRIVER( hackypac )	/* Widel's Games */
	DRIVER( madpac )	/* Widel's Games */
	DRIVER( aa )		/* Widel's Games */
	DRIVER( bace )		/* Widel's Games */
	DRIVER( dderby )	/* Widel's Games */
	DRIVER( kangaroh )	/* Widel's Games */
//	DRIVER( ladybugh )	/* Widel's Games */
	DRIVER( mrmrspac )	/* Widel's Games */
	DRIVER( mspachi )	/* Widel's Games */
	DRIVER( pactest )	/* Widel's Games */
	DRIVER( ppong )		/* Widel's Games */
	DRIVER( ppong2 )	/* Widel's Games */
	DRIVER( rainboh )	/* Widel's Games */
	DRIVER( zap )		/* Widel's Games */

	DRIVER( alpaca7 )	/* Jerronimo */
	DRIVER( alpaca8 )	/* Jerronimo */
	DRIVER( horizpac )	/* Jerronimo */
	DRIVER( horizpab )	/* Jerronimo v1.0 2004 */
	DRIVER( pachello )	/* Jerronimo */
	DRIVER( pacman25 )	/* Jerronimo v1.0 2004 */
	DRIVER( pacmatri )	/* Jerronimo */
	DRIVER( pacsnoop )	/* Jerronimo */
	DRIVER( ramsnoop )	/* Jerronimo */
	DRIVER( seq1 )		/* Jerronimo */
	DRIVER( seq2 )		/* Jerronimo */

	DRIVER( tst_pacm )
	DRIVER( fasthang )
	DRIVER( fastpop )
	DRIVER( fastpuck )
	DRIVER( fstpman2 )
	DRIVER( pacrab )
	DRIVER( zolamaze )
	DRIVER( zolaad )	/* PacMAME Hacks */
	DRIVER( zolaatk )	/* PacMAME Hacks */
	DRIVER( zolapac )	/* PacMAME Hacks */
	DRIVER( zolaslow )	/* PacMAME Hacks */
	DRIVER( zolatunl )	/* PacMAME Hacks */
	DRIVER( zolavect )	/* PacMAME Hacks */
	DRIVER( lazybug )
	DRIVER( lazybug1 )
	DRIVER( wavybug )
	DRIVER( mspacii )
	DRIVER( mtturbo )	/* Tim - Make Trax Turbo Hack */
	DRIVER( pm4n1 )
	DRIVER( pm4n1a )
	DRIVER( pm4n1b )
	DRIVER( pm4n1c )
	DRIVER( pm4n1d )
	DRIVER( pm4n1e )
	DRIVER( mspacj )
	DRIVER( pacgalu )
	DRIVER( pheartb )
	DRIVER( cottoh )	/* Gatinho hack of mspacman, to simulate what Crazy Otto might have been like */
	DRIVER( cottoh2 )	/* Gatinho hack of mspacman, to simulate what Crazy Otto might have been like */

	/* pacmanx.c */
	/* "Pacman hardware" games (hires hacks) */
	DRIVER( puckmanx ) 	/* (c) 1980 Namco */
	DRIVER( puckmnax ) 	/* (c) 1980 Namco */
	DRIVER( puckmnfx ) 	/* hack */
	DRIVER( puckmnhx ) 	/* hack */
	DRIVER( pacmanx ) 	/* (c) 1980 Midway */
	DRIVER( pacmanfx ) 	/* hack */
	DRIVER( puckmodx ) 	/* (c) 1981 Namco */
	DRIVER( pacmodx ) 	/* (c) 1981 Midway */
	DRIVER( newpuc2x ) 	/* hack */
	DRIVER( nwpuc2bx ) 	/* hack */
	DRIVER( nwpuckxx ) 	/* hack */
	DRIVER( pheartx ) 	/* hack */
	DRIVER( hanglyx ) 	/* hack */
	DRIVER( hangly2x ) 	/* hack */
	DRIVER( hangly3x ) 	/* hack */
	DRIVER( pacplusx )
	DRIVER( mspacmnx ) 	/* (c) 1981 Midway */ /* made by Gencomp */
	DRIVER( mspacmfx ) 	/* hack */
	DRIVER( mspacatx ) 	/* hack */
	DRIVER( mspacmbx ) 	/* bootleg */
	DRIVER( pacgalx ) 	/* hack */
	DRIVER( mspacplx ) 	/* hack */
	DRIVER( mschampx ) 	/* hack */

	/* pcktgal.c */
	DRIVER( pckgalgr )	/* Vag @ GreekRoms */
	DRIVER( pcktgalk )	/* Korean Translation */

	/* pengo.c */
	DRIVER( pengohs )	/* JROK */
	DRIVER( pengopop )
	DRIVER( vecpengo )	/* T-Bone hack of Pengo */
	DRIVER( alpacap7 )	/* "Jerronimo", "Alpaca v0.7 (Pengo Hardware) */
	DRIVER( alpacap8 )	/* "Jerronimo", "Alpaca v0.8 (Pengo Hardware) */

	/* pgm.c */
	DRIVER( pgemeni )	/* Blastar */
	DRIVER( pgmdemo )	/* Charles Doty */
	DRIVER( pgmfrog )	/* Rastersoft */

	/* phoenix.c */
//	DRIVER( phoenix4 )	/* rom missing */
	DRIVER( phoenixd )
	DRIVER( phoenixg )	/* Vag @ GreekRoms */
	DRIVER( phoenixr )	/* CYBERYOGI =CO= Windler hack of Phoenix */
	DRIVER( pleiads2 )

	/* playch10.c */
	DRIVER( pc_bb2 )	/* NES->PC-10 */
	DRIVER( pc_ctfrc )	/* NES->PC-10 */
	DRIVER( pc_digdg )	/* NES->PC-10 */
	DRIVER( pc_krsty )	/* NES->PC-10 */
	DRIVER( pc_mman5 )	/* NES->PC-10 */
	DRIVER( pc_parsl )	/* NES->PC-10 */
	DRIVER( pc_ark )	/* NES->PC-10 */
	DRIVER( pc_dk3 )	/* NES->PC-10 */
	DRIVER( pc_galag )	/* NES->PC-10 */
	DRIVER( pc_cch )	/* NES->PC-10 */
	DRIVER( pc_dk )		/* NES->PC-10 */
	DRIVER( pc_pacm )	/* NES->PC-10 */
	DRIVER( pc_gyrus )	/* NES->PC-10 */
	DRIVER( pc_skykd )	/* NES->PC-10 */

	/* pong.c */
	DRIVER( pong )

	/* rallyx.c */
	DRIVER( rxtron )	/* Jerky and Sil hack of Rally-X */
	DRIVER( nrallyv )	/* New Rally-X (vertical) */

	/* rastan.c */
	DRIVER( rastandh )	/* Neil Pearce Hack */	
	DRIVER( rastand2 )	/* Neil Pearce Hack */
	DRIVER( rastaneh )	/* Neil Pearce Hack */
	DRIVER( rastane2 )	/* Neil Pearce Hack */
	DRIVER( rastwack )	/* Vogel Hack */

	/* rockola.c */
	DRIVER( vantris )	/* (c) 1998 Norbert Kehrer */

	/* seagc2.c */
	DRIVER( c2frog )

	/* segar.c */
	DRIVER( astrob2h )

	/* shaolins.c */
	DRIVER( kfjohnny )	/* hack by Smitdogg*/

	/* st0016.c */
	DRIVER( renjuk )	/* Korean Translation */

	/* system1.c */
	DRIVER( wbmlbit )	/* Italian Translation */
	DRIVER( wbmlkb )	/* Korean Translation */

	/* system16.c */
	DRIVER( sys16dem )	/* Charles Doty */

	/* taito_b.c */
	DRIVER( bubbleb ) 	/* pbobble USA Region Hack */

	/* taito_f2.c */
	DRIVER( f2demo )	/* Charles Doty */

	/* taito_f3.c */
	DRIVER( arkretrh )
	DRIVER( cleopath )
	DRIVER( driusgxh )
//	DRIVER( f3demo )	/* Charles Doty - removed - not working */
	DRIVER( gekiridh )
	DRIVER( landmakh )
	DRIVER( pbobl2xh )

	/* tecmo.c */
	DRIVER( geminit )	/* Twisty Hack */
	DRIVER( rygark )	/* Korean Translation */

	/* tehkanwc.c */
	DRIVER( ballonwc )
	DRIVER( tehkangc )
	DRIVER( tankwc )
	DRIVER( twc_gr )	/* Vag @ GreekRoms */

	/* tempest.c */
	DRIVER( tempall )
	DRIVER( temped )	/* Tempest TempEd Hack */
	DRIVER( tempestm )
	DRIVER( temptwst )	/* Twisty Hack */
	DRIVER( tmptwsta )	/* Twisty Hack 2000 */
	DRIVER( tmptwst2 )	/* Twisty Hack */
	DRIVER( tmptwst3 )	/* Twisty Hack */
	DRIVER( tmptwst4 )	/* Twisty Hack */
	DRIVER( vbrakout )	/* Clay Cowgill Multi-Tempest */
	DRIVER( tempmg )
	DRIVER( temptlm )
	DRIVER( vortex )	/* Tempest Prototype */
	DRIVER( vortexa )	/* Tempest Prototype */
	DRIVER( aliensv )	/* Tempest Prototype */
	DRIVER( aliensva )	/* Tempest Prototype */

	/* terracre.c */
	DRIVER( terracrc )
	
	/* timeplt.c */
	DRIVER( timephs )

	/* tnzs.c */
	DRIVER( arkn2hs )
	DRIVER( arkn2hsu )

	/* toaplan2.c */
	DRIVER( kgpe )		/* Neill Corlett hack */

	/* tp84.c */
	DRIVER( tp84hs )

	/* trackfld.c */
	DRIVER( athens04 )	/* Athens 2004 - Hack by The Gameland Crew (http://www.gameland.gr): Maddog, Whacker, Badge, Geoanas */

	/* twincobr.c */
	DRIVER( twincbu2 )
	DRIVER( twintwst )

	/* volfied.c */
	DRIVER( volfiedg )	/* Vag @ GreekRoms 2005 */

	/* vsnes.c */
	DRIVER( mrio2002 )	/* Vs. Super Mario Bros. 2002 */
	DRIVER( suprsktr )	/* Vs. Super Skater Bros. - Vs. Super Mario Skaters */

	/* williams.c */
	DRIVER( defendr2 )
	DRIVER( splatsc1 )
	DRIVER( wmg )		/* Clay Cowgill (6-game version) */

	/* yiear.c */
	DRIVER( nacho )		/* Gatinho - Nacho Libre */


#endif	/* DRIVER_RECURSIVE */
